@@ -3,6 +3,8 @@ package mini
 import (
 	"bytes"
 	"context"
+	"crypto/ed25519"
+	crand "crypto/rand"
 	"encoding/base64"
 	"encoding/json"
 	"fmt"
@@ -19,6 +21,7 @@ import (
 	"moul.io/godev"
 
 	"berty.tech/berty/v2/go/internal/bertylinks"
+	"berty.tech/berty/v2/go/pkg/bertyvcissuer"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
 	"berty.tech/berty/v2/go/pkg/protocoltypes"
@@ -144,6 +147,11 @@ func commandList() []*command {
 			help:  "Shows IPFS debug information",
 			cmd:   debugIPFSCommand,
 		},
+		{
+			title: "contact refresh",
+			help:  "refresh contact request",
+			cmd:   refreshCommand,
+		},
 		{
 			title: "debug system",
 			help:  "Shows system debug information",
@@ -199,6 +207,16 @@ func commandList() []*command {
 			help:  `Saves an export of the current instance to the specified path`,
 			cmd:   exportAccount,
 		},
+		{
+			title: "services credential init",
+			help:  `Inits a credential verification flow`,
+			cmd:   credentialVerificationInit,
+		},
+		{
+			title: "services credential complete",
+			help:  `Completes a credential verification flow`,
+			cmd:   credentialVerificationComplete,
+		},
 		{
 			title:     "/",
 			help:      "",
@@ -224,6 +242,64 @@ func sendReplyOptions(ctx context.Context, v *groupView, cmd string) error {
 	return err
 }
 
+func credentialVerificationInit(ctx context.Context, v *groupView, service string) error {
+	// TODO: move this to bertyprotocol
+	// FIXME: use a non volatile identity
+	pub, priv, err := ed25519.GenerateKey(crand.Reader)
+	if err != nil {
+		return err
+	}
+
+	_, webLink, err := bertylinks.MarshalLink(&messengertypes.BertyLink{
+		Kind: messengertypes.BertyLink_ContactInviteV1Kind,
+		BertyID: &messengertypes.BertyID{
+			PublicRendezvousSeed: []byte("testseed"),
+			AccountPK:            pub[:],
+			DisplayName:          "test link",
+		},
+	})
+	if err != nil {
+		return err
+	}
+
+	v.vcClient = bertyvcissuer.NewClient(service)
+	ctx, cancel := context.WithTimeout(ctx, time.Second*10)
+	defer cancel()
+
+	url, err := v.vcClient.Init(ctx, webLink, priv)
+	if err != nil {
+		return err
+	}
+
+	v.messages.Append(&historyMessage{
+		messageType: messageTypeMeta,
+		payload:     []byte(fmt.Sprintf("Auth URL: %s", url)),
+	})
+	copyToClipboard(v, url)
+
+	return nil
+}
+
+func credentialVerificationComplete(ctx context.Context, v *groupView, callbackURI string) error {
+	if v.vcClient == nil {
+		return fmt.Errorf("no verification process has been started")
+	}
+
+	_, identifier, err := v.vcClient.Complete(callbackURI)
+	if err != nil {
+		return err
+	}
+
+	v.messages.Append(&historyMessage{
+		messageType: messageTypeMeta,
+		payload:     []byte(fmt.Sprintf("Completed authentication, associated identifier is <%s>", identifier)),
+	})
+
+	v.vcClient = nil
+
+	return nil
+}
+
 func exportAccount(ctx context.Context, v *groupView, path string) error {
 	path = strings.TrimSpace(path)
 
@@ -715,6 +791,61 @@ func groupInviteCommand(renderFunc func(*groupView, string)) func(ctx context.Co
 	}
 }
 
+func refreshCommand(ctx context.Context, v *groupView, cmd string) error {
+	contactspk := [][]byte{}
+	v.v.lock.Lock()
+	for k, state := range v.v.contactStates {
+		switch state {
+		case protocoltypes.ContactStateToRequest, protocoltypes.ContactStateAdded:
+			contactspk = append(contactspk, []byte(k))
+		default:
+		}
+	}
+	v.v.lock.Unlock()
+
+	for _, pk := range contactspk {
+		go func(pk []byte) {
+			ctx, cancel := context.WithTimeout(ctx, time.Second*20)
+			defer cancel()
+
+			v.syncMessages <- &historyMessage{
+				messageType: messageTypeMeta,
+				payload:     []byte("refreshing..."),
+			}
+
+			res, err := v.v.protocol.RefreshContactRequest(ctx, &protocoltypes.RefreshContactRequest_Request{
+				ContactPK: pk,
+			})
+
+			switch {
+			case err != nil:
+				emsg := fmt.Sprintf("refresh: unable to connect to peer: %s", err.Error())
+				v.syncMessages <- &historyMessage{
+					messageType: messageTypeError,
+					payload:     []byte(emsg),
+				}
+
+			case len(res.PeersFound) == 0:
+				v.syncMessages <- &historyMessage{
+					messageType: messageTypeError,
+					payload:     []byte("refresh: no peers found"),
+				}
+
+			default:
+				for _, p := range res.PeersFound {
+					msg := fmt.Sprintf("refresh: succefully connected to peer: %s", p.ID)
+					v.syncMessages <- &historyMessage{
+						messageType: messageTypeMeta,
+						payload:     []byte(msg),
+					}
+				}
+			}
+		}(pk)
+	}
+
+	return nil
+}
+
 func cmdHelp(ctx context.Context, v *groupView, cmd string) error {
 	longestCmd := 0
 
