@@ -20,6 +20,7 @@ import (
 	ipfs_p2p "github.com/ipfs/go-ipfs/core/node/libp2p"
 	ipfs_repo "github.com/ipfs/go-ipfs/repo"
 	libp2p "github.com/libp2p/go-libp2p"
+	p2p_disc "github.com/libp2p/go-libp2p-core/discovery"
 	"github.com/libp2p/go-libp2p-core/host"
 	"github.com/libp2p/go-libp2p-core/peer"
 	peerstore "github.com/libp2p/go-libp2p-core/peerstore"
@@ -74,6 +75,7 @@ const (
 	FlagNameP2PTinderDiscover             = "p2p.tinder-discover"
 	FlagNameP2PTinderDHTDriver            = "p2p.tinder-dht-driver"
 	FlagNameP2PTinderRDVPDriver           = "p2p.tinder-rdvp-driver"
+	FlagNameP2PTinderLocalDiscoveryDriver = "p2p.tinder-localdiscovery-driver"
 	FlagNameP2PDisableDiscoverAddrsFilter = "p2p.disc-disable-filter"
 
 	FlagValueP2PDHTDisabled   = "none"
@@ -101,10 +103,11 @@ func (m *Manager) SetupLocalIPFSFlags(fs *flag.FlagSet) {
 	fs.BoolVar(&m.Node.Protocol.TinderDiscover, FlagNameP2PTinderDiscover, true, "if true enable tinder discovery")
 	fs.BoolVar(&m.Node.Protocol.TinderDHTDriver, FlagNameP2PTinderDHTDriver, true, "if true dht driver will be enable for tinder")
 	fs.BoolVar(&m.Node.Protocol.TinderRDVPDriver, FlagNameP2PTinderRDVPDriver, true, "if true rdvp driver will be enable for tinder")
+	fs.BoolVar(&m.Node.Protocol.TinderLocalDiscoveryDriver, FlagNameP2PTinderLocalDiscoveryDriver, true, "if true localdiscovery driver will be enable for tinder")
 	fs.BoolVar(&m.Node.Protocol.DisableDiscoverFilterAddrs, FlagNameP2PDisableDiscoverAddrsFilter, false, "dont filter private addrs on discovery service")
 	fs.BoolVar(&m.Node.Protocol.AutoRelay, "p2p.autorelay", true, "enable autorelay, force private reachability")
 	fs.StringVar(&m.Node.Protocol.StaticRelays, FlagNameP2PStaticRelays, KeywordDefault, "list of static relay maddrs, `:default:` will use statics relays from the config")
-	fs.DurationVar(&m.Node.Protocol.MinBackoff, "p2p.min-backoff", time.Minute, "minimum p2p backoff duration")
+	fs.DurationVar(&m.Node.Protocol.MinBackoff, "p2p.min-backoff", time.Second, "minimum p2p backoff duration")
 	fs.DurationVar(&m.Node.Protocol.MaxBackoff, "p2p.max-backoff", time.Minute*10, "maximum p2p backoff duration")
 	fs.DurationVar(&m.Node.Protocol.PollInterval, "p2p.poll-interval", pubsub.DiscoveryPollInterval, "how long the discovery system will waits for more peers")
 	fs.StringVar(&m.Node.Protocol.RdvpMaddrs, FlagNameP2PRDVP, KeywordDefault, "list of rendezvous point maddr, `:dev:` will add the default devs servers, `:none:` will disable rdvp")
@@ -219,13 +222,27 @@ func (m *Manager) getLocalIPFS() (ipfsutil.ExtendedCoreAPI, *ipfs_core.IpfsNode,
 	// setup mdns
 	if m.Node.Protocol.MDNS.Enable && !m.Node.Protocol.DisableIPFSNetwork {
 		h := mnode.PeerHost()
-		dh := ipfsutil.DiscoveryHandler(ctx, logger, h)
-		mdnsService := ipfsutil.NewMdnsService(logger, h, ipfsutil.MDNSServiceName, dh)
-		logger.Named("mdns").Info("starting mdns")
-		if err := mdnsService.Start(); err != nil {
+		mdnslogger := logger.Named("mdns")
+
+		dh := ipfsutil.DiscoveryHandler(ctx, mdnslogger, h)
+		mdnsService := ipfsutil.NewMdnsService(mdnslogger, h, ipfsutil.MDNSServiceName, dh)
+
+		// get multicast interfaces
+		ifaces, err := ipfsutil.GetMulticastInterfaces()
+		if err != nil {
 			return nil, nil, errcode.ErrIPFSInit.Wrap(err)
 		}
 
+		// if multicast interfaces is found, start mdns service
+		if len(ifaces) > 0 {
+			mdnslogger.Info("starting mdns")
+			if err := mdnsService.Start(); err != nil {
+				return nil, nil, errcode.ErrIPFSInit.Wrap(err)
+			}
+		} else {
+			mdnslogger.Error("unable to start mdns service, no multicast interfaces found")
+		}
+
 		m.Node.Protocol.mdnsService = mdnsService
 	}
 
@@ -335,14 +352,19 @@ func (m *Manager) setupIPFSRepo(ctx context.Context) (*ipfs_mobile.RepoMobile, e
 		return nil, errcode.ErrKeystoreGet.Wrap(err)
 	}
 
+	storageSalt, err := m.GetAccountStorageSalt()
+	if err != nil {
+		return nil, errcode.ErrKeystoreGet.Wrap(err)
+	}
+
 	dbPath := filepath.Join(m.Datastore.Dir, "ipfs.sqlite")
 
-	repo, err = ipfsutil.LoadRepoFromPath(dbPath, storageKey)
+	repo, err = ipfsutil.LoadRepoFromPath(dbPath, storageKey, storageSalt)
 	if err != nil {
 		return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
 	}
 
-	repo, err = m.resetRepoIdentityIfExpired(ctx, repo, dbPath, storageKey)
+	repo, err = m.resetRepoIdentityIfExpired(ctx, repo, dbPath, storageKey, storageSalt)
 	if err != nil {
 		return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
 	}
@@ -350,7 +372,7 @@ func (m *Manager) setupIPFSRepo(ctx context.Context) (*ipfs_mobile.RepoMobile, e
 	return ipfs_mobile.NewRepoMobile(dbPath, repo), nil
 }
 
-func (m *Manager) resetRepoIdentityIfExpired(ctx context.Context, repo ipfs_repo.Repo, dbPath string, storageKey []byte) (ipfs_repo.Repo, error) {
+func (m *Manager) resetRepoIdentityIfExpired(ctx context.Context, repo ipfs_repo.Repo, dbPath string, storageKey []byte, storageSalt []byte) (ipfs_repo.Repo, error) {
 	rootDS, err := m.getRootDatastore()
 	if err != nil {
 		return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
@@ -378,7 +400,7 @@ func (m *Manager) resetRepoIdentityIfExpired(ctx context.Context, repo ipfs_repo
 	}
 
 	if lastUpdate.Before(time.Now().Add(-rendezvousRotationBase)) {
-		repo, err = ipfsutil.ResetExistingRepoIdentity(repo, dbPath, storageKey)
+		repo, err = ipfsutil.ResetExistingRepoIdentity(repo, dbPath, storageKey, storageSalt)
 		if err != nil {
 			return nil, errcode.ErrInternal.Wrap(err)
 		}
@@ -505,6 +527,7 @@ func (m *Manager) setupIPFSConfig(cfg *ipfs_cfg.Config) ([]libp2p.Option, error)
 		cfg.Swarm.RelayClient.Enabled = ipfs_cfg.True
 	} else {
 		cfg.Swarm.RelayClient.Enabled = ipfs_cfg.False
+		cfg.Swarm.Transports.Network.Relay = ipfs_cfg.False
 	}
 
 	pis, err := m.getStaticRelays()
@@ -568,6 +591,22 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 	// configure tinder drivers
 	var drivers []*tinder.Driver
 
+	// localdiscovery driver
+	if m.Node.Protocol.TinderLocalDiscoveryDriver {
+		m.Node.Protocol.localdisc, err = tinder.NewLocalDiscovery(logger, h, rng)
+		if err != nil {
+			return errcode.ErrIPFSSetupHost.Wrap(err)
+		}
+
+		filter := tinder.PrivateAddrOnly
+		if m.Node.Protocol.DisableDiscoverFilterAddrs {
+			filter = tinder.NoFilter
+		}
+
+		drivers = append(drivers,
+			tinder.NewDriverFromUnregisterDiscovery(tinder.LocalDiscoveryName, m.Node.Protocol.localdisc, filter))
+	}
+
 	// rdvp driver
 	if m.Node.Protocol.TinderRDVPDriver {
 		rdvpfilter := tinder.PublicAddrsOnly
@@ -625,7 +664,13 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 	// @FIXME(gfanton): hacky way to to handle close on context done
 	go func() {
 		<-m.getContext().Done()
+
 		m.Node.Protocol.discovery.Close()
+
+		if m.Node.Protocol.localdisc != nil {
+			m.Node.Protocol.localdisc.Close()
+		}
+
 		if m.Node.Protocol.MDNS.Enable && m.Node.Protocol.MDNS.DriverLocker != nil {
 			m.Node.Protocol.MDNS.DriverLocker.Unlock()
 		}
@@ -648,16 +693,25 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 		pt.EventTracerOption(),
 	}
 
+	var disc p2p_disc.Discovery
 	if m.Node.Protocol.TinderDiscover {
-		popts = append(popts, pubsub.WithDiscovery(m.Node.Protocol.discovery, pubsub.WithDiscoverConnector(backoffconnector)))
+		// filter localdiscovery from drivers since pubsub automatically share topic between connected peers
+		disc = tinder.NewFilterDriverDiscovery(m.Node.Protocol.discovery, tinder.LocalDiscoveryName)
 	} else {
-		advertiseOnly := tinder.DriverDiscovery{
+		disc = tinder.DriverDiscovery{
 			Discoverer: tinder.NoopDiscovery,
 			Advertiser: m.Node.Protocol.discovery,
 		}
-		popts = append(popts, pubsub.WithDiscovery(advertiseOnly, pubsub.WithDiscoverConnector(backoffconnector)))
 	}
 
+	// rp, err := m.getRotationInterval()
+	// if err != nil {
+	// 	return errcode.ErrIPFSSetupHost.Wrap(err)
+	// }
+
+	// disc = tinder.NewRotationDiscovery(logger.Named("rotation"), disc, rp)
+	popts = append(popts, pubsub.WithDiscovery(disc, pubsub.WithDiscoverConnector(backoffconnector)))
+
 	// pubsub.DiscoveryPollInterval = m.Node.Protocol.PollInterval
 	m.Node.Protocol.pubsub, err = pubsub.NewGossipSub(m.getContext(), h, popts...)
 	if err != nil {
