@@ -244,7 +244,7 @@ func (d *DBWrapper) AddConversationForContact(groupPK, ownMemberPK, ownDevicePK,
 	if err != nil {
 		return nil, err
 	}
-	d.logStep("Maybed added conversation to db", tyber.WithJSONDetail("ConversationToSave", conversation), tyber.WithJSONDetail("FinalConversation", finalConv))
+	d.logStep("Maybe added conversation to db", tyber.WithJSONDetail("ConversationToSave", conversation), tyber.WithJSONDetail("FinalConversation", finalConv))
 	return finalConv, nil
 }
 
@@ -1087,6 +1087,7 @@ func (d *DBWrapper) AddMember(memberPK, groupPK, displayName, avatarCID string,
 		AvatarCID:             avatarCID,
 		IsCreator:             isCreator,
 		IsMe:                  isMe,
+		DisplayName:           displayName,
 	}
 
 	if err := d.TX(d.ctx, func(tx *DBWrapper) error {
@@ -1098,16 +1099,6 @@ func (d *DBWrapper) AddMember(memberPK, groupPK, displayName, avatarCID string,
 			return err
 		}
 
-		// Ensure a display name
-		if displayName == "" {
-			nameSuffix := "1337"
-			if len(memberPK) >= 4 {
-				nameSuffix = memberPK[:4]
-			}
-			displayName = "anon#" + nameSuffix
-		}
-		member.DisplayName = displayName
-
 		return tx.db.Create(&member).Error
 	}); errors.Is(err, errcode.ErrDBEntryAlreadyExists) {
 		return member, err
@@ -1135,14 +1126,6 @@ func (d *DBWrapper) UpsertMember(memberPK, groupPK string, m messengertypes.Memb
 		return nil, isNew, errcode.ErrDBRead.Wrap(err)
 	}
 
-	if em.GetDisplayName() == "" && m.DisplayName == "" {
-		nameSuffix := "1337"
-		if len(memberPK) >= 4 {
-			nameSuffix = memberPK[:4]
-		}
-		m.DisplayName = "anon#" + nameSuffix
-	}
-
 	if isNew {
 		err := d.db.Create(&m).Error
 		if err != nil {
