@@ -9,10 +9,20 @@ import (
 type tinderOption string
 
 const (
-	optionKeepContext  tinderOption = "keepctx"
-	optionFilterDriver tinderOption = "filterdriver"
+	optionKeepContext                tinderOption = "keepctx"
+	optionFilterDriver               tinderOption = "filterdriver"
+	optionRendezvousUseDiscoverAsync tinderOption = "rendezvoususediscoverasync"
+	optionForce                      tinderOption = "force"
 )
 
+func WatchdogDiscoverForceOption(opts *p2p_discovery.Options) error {
+	if opts.Other == nil {
+		opts.Other = make(map[interface{}]interface{})
+	}
+	opts.Other[optionForce] = true
+	return nil
+}
+
 func WatchdogDiscoverKeepContextOption(opts *p2p_discovery.Options) error {
 	if opts.Other == nil {
 		opts.Other = make(map[interface{}]interface{})
@@ -21,6 +31,14 @@ func WatchdogDiscoverKeepContextOption(opts *p2p_discovery.Options) error {
 	return nil
 }
 
+func RendezvousUseDiscoverAsyncOption(opts *p2p_discovery.Options) error {
+	if opts.Other == nil {
+		opts.Other = make(map[interface{}]interface{})
+	}
+	opts.Other[optionRendezvousUseDiscoverAsync] = true
+	return nil
+}
+
 // FilterDriverNameOption filter driver by prefix name
 func FilterDriverNameOption(driversName ...string) p2p_discovery.Option {
 	return func(opts *p2p_discovery.Options) error {
