@@ -31,6 +31,7 @@ type watchdogsDiscoverer struct {
 
 	logger        *zap.Logger
 	disc          p2p_discovery.Discoverer
+	mdisc         p2p_discovery.Discoverer
 	resetInterval time.Duration
 
 	findpeers   map[string]*findPeersTimer
@@ -61,6 +62,7 @@ func newWatchdogsDiscoverer(ctx context.Context, l *zap.Logger, h host.Host, res
 		findpeers:     make(map[string]*findPeersTimer),
 		logger:        l,
 		disc:          disc,
+		mdisc:         mdisc,
 	}, nil
 }
 
@@ -75,6 +77,11 @@ func (w *watchdogsDiscoverer) FindPeers(ctx context.Context, ns string, opts ...
 		ctx = w.rootctx
 	}
 
+	// if `force` option is passed, ignore cache and trigger a find peers directly
+	if _, force := options.Other[optionForce]; force {
+		return w.mdisc.FindPeers(ctx, ns, opts...)
+	}
+
 	w.mufindpeers.Lock()
 	defer w.mufindpeers.Unlock()
 
