@@ -14,7 +14,6 @@ import (
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/protocoltypes"
 	ipfslog "berty.tech/go-ipfs-log"
-	"berty.tech/go-orbit-db/events"
 	"berty.tech/go-orbit-db/iface"
 )
 
@@ -44,7 +43,6 @@ type metadataStoreIndex struct {
 	ownMemberDevice          *cryptoutil.MemberDevice
 	deviceKeystore           cryptoutil.DeviceKeystore
 	ctx                      context.Context
-	eventEmitter             events.EmitterInterface
 	lock                     sync.RWMutex
 	logger                   *zap.Logger
 }
@@ -65,7 +63,7 @@ func (m *metadataStoreIndex) UpdateIndex(log ipfslog.Log, _ []ipfslog.Entry) err
 	m.lock.Lock()
 	defer m.lock.Unlock()
 
-	entries := log.Values().Slice()
+	entries := log.GetEntries().Slice()
 
 	// Resetting state
 	m.contacts = map[string]*AccountContact{}
@@ -881,8 +879,9 @@ func (m *metadataStoreIndex) postHandlerSentAliases() error {
 	return nil
 }
 
+// nolint:staticcheck
 // newMetadataIndex returns a new index to manage the list of the group members
-func newMetadataIndex(ctx context.Context, eventEmitter events.EmitterInterface, g *protocoltypes.Group, md *cryptoutil.MemberDevice, devKS cryptoutil.DeviceKeystore) iface.IndexConstructor {
+func newMetadataIndex(ctx context.Context, g *protocoltypes.Group, md *cryptoutil.MemberDevice, devKS cryptoutil.DeviceKeystore) iface.IndexConstructor {
 	return func(publicKey []byte) iface.StoreIndex {
 		m := &metadataStoreIndex{
 			members:                map[string][]*cryptoutil.MemberDevice{},
@@ -897,7 +896,6 @@ func newMetadataIndex(ctx context.Context, eventEmitter events.EmitterInterface,
 			contactRequestMetadata: map[string][]byte{},
 			membersPushTokens:      map[string]*protocoltypes.PushMemberTokenUpdate{},
 			g:                      g,
-			eventEmitter:           eventEmitter,
 			ownMemberDevice:        md,
 			deviceKeystore:         devKS,
 			ctx:                    ctx,
