@@ -12,10 +12,10 @@ import BlueDevAvatar from '@berty/assets/images/berty_dev_blue_bg.png'
 import GreenDevAvatar from '@berty/assets/images/berty_dev_green_bg.png'
 import Logo from '@berty/assets/logo/1_berty_picto.svg'
 import { useStyles } from '@berty/contexts/styles'
-import { useAccount, useContact, useConversation, useMember } from '@berty/hooks'
+import { useAccount, useContact, useConversation, useMember, useThemeColor } from '@berty/hooks'
 import { navigate } from '@berty/navigation'
 import { selectPersistentOptions } from '@berty/redux/reducers/persistentOptions.reducer'
-import { Maybe, useThemeColor } from '@berty/store'
+import { Maybe } from '@berty/utils/type/maybe'
 
 import AttachmentImage from './AttachmentImage'
 import { UnifiedText } from './shared-components/UnifiedText'
