@@ -5,7 +5,7 @@ import beapi from '@berty/api'
 import { ChatDate } from '@berty/components/chat/ChatDate'
 import { MessageSystemWrapper } from '@berty/components/chat/message/MessageSystemWrapper'
 import { useStyles } from '@berty/contexts/styles'
-import { useThemeColor } from '@berty/store/hooks'
+import { useThemeColor } from '@berty/hooks'
 
 import { UnifiedText } from '../shared-components/UnifiedText'
 
