@@ -12,6 +12,7 @@ import { RESULTS } from 'react-native-permissions'
 import { useSafeAreaInsets } from 'react-native-safe-area-context'
 
 import beapi from '@berty/api'
+import { ChatTextInput } from '@berty/components'
 import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
 import { useModal } from '@berty/contexts/modal.context'
 import {
@@ -20,6 +21,9 @@ import {
 	useMedias,
 	useConversation,
 	usePlaySound,
+	useThemeColor,
+	useMessengerClient,
+	useMountEffect,
 } from '@berty/hooks'
 import { useNavigation } from '@berty/navigation'
 import {
@@ -37,20 +41,19 @@ import {
 	setChatInputIsSending,
 	setChatInputSelection,
 } from '@berty/redux/reducers/chatInputsVolatile.reducer'
-import { Maybe, useMessengerClient, useMountEffect, useThemeColor } from '@berty/store'
 import rnutil from '@berty/utils/react-native'
 import { PermissionType } from '@berty/utils/react-native/permissions'
+import { Maybe } from '@berty/utils/type/maybe'
 
 import { AddFileMenu } from '../modals/add-file-modal/AddFileMenu.modal'
 import { CameraButton, MoreButton, RecordButton, SendButton } from './ChatFooterButtons'
-import { ChatTextInput } from './ChatTextInput'
 import { EmojiBanner } from './emojis/EmojiBanner'
 import { RecordComponent } from './record/RecordComponent'
 
 type ChatFooterProps = {
 	convPK: string
+	placeholder: string
 	disabled?: Maybe<boolean>
-	placeholder?: Maybe<string>
 }
 
 const amap = async <T extends any, C extends (value: T) => any>(arr: T[], cb: C) =>
@@ -340,13 +343,13 @@ export const ChatFooter: React.FC<ChatFooterProps> = React.memo(
 								)}
 							</View>
 							<ChatTextInput
-								disabled={(!isFocused && sending) || disabled}
-								handleTabletSubmit={handlePressSend}
+								editable={!sending && !disabled}
 								placeholder={sending ? t('chat.sending') : placeholder}
-								onFocusChange={setIsFocused}
 								onChangeText={handleTextChange}
 								onSelectionChange={handleSelectionChange}
 								value={message}
+								onFocusChange={setIsFocused}
+								handleTabletSubmit={handlePressSend}
 								convPK={convPK}
 							/>
 							<View style={{ marginLeft: horizontalGutter }}>
