@@ -1,3 +1,4 @@
+import { Player } from '@react-native-community/audio-toolkit'
 import { Icon } from '@ui-kitten/components'
 import React, { useMemo, useState } from 'react'
 import { useTranslation } from 'react-i18next'
@@ -6,7 +7,7 @@ import { readFile } from 'react-native-fs'
 
 import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
 import { useStyles } from '@berty/contexts/styles'
-import { useThemeColor } from '@berty/store'
+import { useThemeColor } from '@berty/hooks'
 import { playSoundFile } from '@berty/utils/sound/sounds'
 
 import {
@@ -38,7 +39,7 @@ export const PreviewComponent: React.FC<{
 	const { scaleSize } = useAppDimensions()
 	const colors = useThemeColor()
 	const { t } = useTranslation()
-	const [player, setPlayer] = useState<any>(null)
+	const [player, setPlayer] = useState<Player>()
 	const isPlaying = useMemo(() => player?.isPlaying === true, [player?.isPlaying])
 
 	return (
@@ -59,7 +60,9 @@ export const PreviewComponent: React.FC<{
 					},
 				]}
 				onPress={() => {
-					clearInterval(clearRecordingInterval as any)
+					if (clearRecordingInterval) {
+						clearInterval(clearRecordingInterval)
+					}
 					setHelpMessageValue({
 						message: t('audio.record.tooltip.not-sent'),
 					})
@@ -132,7 +135,7 @@ export const PreviewComponent: React.FC<{
 							),
 							volumeValuesAttached,
 						)}
-						currentTime={isPlaying && player?.currentTime}
+						currentTime={isPlaying && player?.currentTime ? player.currentTime : undefined}
 						duration={recordDuration}
 						color={colors['background-header']}
 					/>
