@@ -17,9 +17,8 @@ import beapi from '@berty/api'
 import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
 import { useStyles } from '@berty/contexts/styles'
 import { WelshMessengerServiceClient } from '@berty/grpc-bridge/welsh-clients.gen'
-import { useAppDispatch } from '@berty/hooks'
+import { useAppDispatch, useMessengerClient, useThemeColor } from '@berty/hooks'
 import { AppDispatch } from '@berty/redux/store'
-import { useMessengerClient, useThemeColor } from '@berty/store'
 import rnutil from '@berty/utils/react-native'
 import { PermissionType } from '@berty/utils/react-native/permissions'
 import { playSound } from '@berty/utils/sound/sounds'
