@@ -7,8 +7,8 @@ import beapi from '@berty/api'
 import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
 import { useMusicPlayer } from '@berty/contexts/musicPlayer.context'
 import { useStyles } from '@berty/contexts/styles'
+import { useThemeColor } from '@berty/hooks'
 import { selectProtocolClient } from '@berty/redux/reducers/ui.reducer'
-import { useThemeColor } from '@berty/store/hooks'
 
 import { UnifiedText } from '../../shared-components/UnifiedText'
 import { normalizeVolumeIntensities, WaveForm } from '../audioMessageCommon'
