@@ -4,16 +4,16 @@ import React, { useState } from 'react'
 import { useTranslation } from 'react-i18next'
 import { View } from 'react-native'
 
-import {
-	TwoHorizontalButtons,
-	SecondaryButtonIconLeft,
-	TertiaryButtonIconLeft,
-} from '@berty/components/buttons'
+import { HorizontalDuo, SecondaryButtonIconLeft, TertiaryButtonIconLeft } from '@berty/components'
 import { useStyles } from '@berty/contexts/styles'
-import { useOneToOneContact, useConversation } from '@berty/hooks'
+import {
+	useOneToOneContact,
+	useConversation,
+	useThemeColor,
+	useMessengerClient,
+} from '@berty/hooks'
 import { useNavigation } from '@berty/navigation'
-import { useMessengerClient, useThemeColor } from '@berty/store'
-import { InteractionGroupInvitation } from '@berty/store/types.gen'
+import { InteractionGroupInvitation } from '@berty/utils/api'
 import { base64ToURLBase64 } from '@berty/utils/convert/base64'
 
 import { MultiMemberAvatar } from '../../avatars'
@@ -118,7 +118,7 @@ const MessageInvitationReceived: React.FC<{ message: InteractionGroupInvitation
 				</UnifiedText>
 			</View>
 			<View style={[margin.top.medium, margin.horizontal.large]}>
-				<TwoHorizontalButtons>
+				<HorizontalDuo>
 					<TertiaryButtonIconLeft
 						disabled
 						name='close-outline'
@@ -131,7 +131,7 @@ const MessageInvitationReceived: React.FC<{ message: InteractionGroupInvitation
 							? t('chat.one-to-one.contact-request-box.accept-button')
 							: t('chat.one-to-one.contact-request-box.accepted-button')}
 					</SecondaryButtonIconLeft>
-				</TwoHorizontalButtons>
+				</HorizontalDuo>
 			</View>
 			{error && (
 				<UnifiedText
