@@ -1,10 +1,10 @@
 import React from 'react'
-import { View } from 'react-native'
+import { StyleProp, View, ViewStyle } from 'react-native'
 
 import Logo from '@berty/assets/logo/1_berty_picto.svg'
 import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
 import { useStyles } from '@berty/contexts/styles'
-import { useThemeColor } from '@berty/store/hooks'
+import { useThemeColor } from '@berty/hooks'
 
 const MessageSystemLogo = () => {
 	const { border, flex, margin, width, height } = useStyles()
@@ -45,8 +45,7 @@ const MessageSystemLogo = () => {
 }
 
 export const MessageSystemWrapper: React.FC<{
-	children: any
-	styleContainer?: any
+	styleContainer?: StyleProp<ViewStyle>
 	logo?: boolean
 }> = ({ children, styleContainer = {}, logo = true }) => {
 	const { padding, border, margin, width } = useStyles()
