@@ -1,4 +1,4 @@
-import { Icon } from '@ui-kitten/components'
+import { Icon, ThemeType } from '@ui-kitten/components'
 import palette from 'google-palette'
 import React, { useCallback, useState } from 'react'
 import { useTranslation } from 'react-i18next'
@@ -15,16 +15,13 @@ import {
 	useAppSelector,
 	useInteractionAuthor,
 	useLastConvInteraction,
+	useMessengerClient,
 	usePlaySound,
+	useThemeColor,
 } from '@berty/hooks'
 import { setActiveReplyInteraction } from '@berty/redux/reducers/chatInputs.reducer'
 import { selectInteraction } from '@berty/redux/reducers/messenger.reducer'
-import {
-	useThemeColor,
-	InteractionUserMessage,
-	ParsedInteraction,
-	useMessengerClient,
-} from '@berty/store'
+import { InteractionUserMessage, ParsedInteraction } from '@berty/utils/api'
 import { pbDateToNum } from '@berty/utils/convert/time'
 import { getMediaTypeFromMedias } from '@berty/utils/messenger/media'
 
@@ -62,10 +59,10 @@ const interactionsFilter = (inte: ParsedInteraction) =>
 const getUserMessageState = (
 	inte: ParsedInteraction,
 	members: { [key: string]: beapi.messenger.IMember | undefined } | undefined,
-	convKind: any,
+	convKind: beapi.messenger.Conversation.Type,
 	previousMessage: ParsedInteraction | undefined,
 	nextMessage: ParsedInteraction | undefined,
-	colors: any,
+	colors: ThemeType,
 ) => {
 	const sentDate = pbDateToNum(inte?.sentDate)
 
@@ -79,18 +76,23 @@ const getUserMessageState = (
 	const cmd = null /*messenger.message.isCommandMessage(payload.body)*/
 	if (convKind === beapi.messenger.Conversation.Type.ContactType) {
 		// State of OneToOne conversation
-		msgTextColor = inte.isMine
-			? inte.acknowledged
-				? colors['reverted-main-text']
-				: cmd
-				? colors['secondary-text']
-				: colors['background-header']
-			: colors['background-header']
-		msgBackgroundColor = inte.isMine
-			? inte.acknowledged
-				? colors['background-header']
-				: colors['reverted-main-text']
-			: colors['input-background']
+
+		// TODO: tmp comment to don't have user frustration when a message is not received
+		// msgTextColor = inte.isMine
+		// 	? inte.acknowledged
+		// 		? colors['reverted-main-text']
+		// 		: colors['background-header']
+		// 	: colors['background-header']
+		msgTextColor = inte.isMine ? colors['reverted-main-text'] : colors['background-header']
+
+		// TODO: tmp comment to don't have user frustration when a message is not received
+		// msgBackgroundColor = inte.isMine
+		// 	? inte.acknowledged
+		// 		? colors['background-header']
+		// 		: colors['reverted-main-text']
+		// 	: colors['input-background']
+		msgBackgroundColor = inte.isMine ? colors['background-header'] : colors['input-background']
+
 		msgBorderColor =
 			inte.isMine &&
 			(cmd
@@ -124,18 +126,27 @@ const getUserMessageState = (
 			const h = new SHA3(256).update(inte.memberPublicKey).digest()
 			baseColor = '#' + pal[h[0]]
 		}
-		msgTextColor = inte.isMine
-			? inte.acknowledged
-				? colors['reverted-main-text']
-				: cmd
-				? colors['secondary-text']
-				: baseColor
-			: colors['reverted-main-text']
-		msgBackgroundColor = inte.isMine
-			? inte.acknowledged
-				? baseColor
-				: colors['reverted-main-text']
-			: baseColor
+		// TODO: tmp comment to don't have user frustration when a message is not received
+		// msgTextColor = inte.isMine
+		// 	? inte.acknowledged
+		// 		? colors['reverted-main-text']
+		// 		: cmd
+		// 		? colors['secondary-text']
+		// 		: baseColor
+		// 	: colors['reverted-main-text']
+		// msgTextColor = inte.isMine
+		// 	? inte.acknowledged
+		// 		? colors['reverted-main-text']
+		// 		: baseColor
+		// 	: colors['reverted-main-text']
+		msgTextColor = colors['reverted-main-text']
+		// TODO: tmp comment to don't have user frustration when a message is not received
+		// msgBackgroundColor = inte.isMine
+		// 	? inte.acknowledged
+		// 		? baseColor
+		// 		: colors['reverted-main-text']
+		// 	: baseColor
+		msgBackgroundColor = baseColor
 		msgBorderColor =
 			inte.isMine && (cmd ? { borderColor: colors['secondary-text'] } : { borderColor: baseColor })
 		msgSenderColor = inte.isMine ? colors['warning-asset'] : baseColor
@@ -158,7 +169,7 @@ export const UserMessage: React.FC<{
 	inte: InteractionUserMessage
 	members?: { [key: string]: beapi.messenger.IMember | undefined }
 	convPK: string
-	convKind: any
+	convKind: beapi.messenger.Conversation.Type
 	previousMessage?: ParsedInteraction
 	nextMessage?: ParsedInteraction
 	replyOf?: ParsedInteraction
@@ -505,7 +516,7 @@ export const UserMessage: React.FC<{
 										{!!(!inte.medias?.length || inte.payload?.body) && (
 											<HyperlinkUserMessage
 												inte={inte}
-												msgBorderColor={msgBorderColor}
+												msgBorderColor={msgBorderColor ? msgBorderColor : undefined}
 												isFollowedMessage={isFollowedMessage}
 												msgBackgroundColor={msgBackgroundColor}
 												msgTextColor={msgTextColor}
