@@ -9,15 +9,11 @@ import tlds from 'tlds'
 import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
 import { useStyles } from '@berty/contexts/styles'
 import { WelshMessengerServiceClient } from '@berty/grpc-bridge/welsh-clients.gen'
+import { useMessengerClient, useThemeColor } from '@berty/hooks'
 import { useNavigation } from '@berty/navigation'
-import {
-	Maybe,
-	useMessengerClient,
-	useThemeColor,
-	InteractionUserMessage,
-	ParsedInteraction,
-} from '@berty/store'
+import { InteractionUserMessage, ParsedInteraction } from '@berty/utils/api'
 import { pbDateToNum, timeFormat } from '@berty/utils/convert/time'
+import { Maybe } from '@berty/utils/type/maybe'
 
 import { UnifiedText } from '../../shared-components/UnifiedText'
 
@@ -61,10 +57,12 @@ export async function isBertyDeepLink(
 
 export const HyperlinkUserMessage: React.FC<{
 	inte: InteractionUserMessage
-	msgBorderColor: any
+	msgBorderColor?: {
+		borderColor: string
+	}
 	isFollowedMessage: boolean | undefined
-	msgBackgroundColor: any
-	msgTextColor: any
+	msgBackgroundColor: string
+	msgTextColor: string
 	isHighlight: boolean
 }> = ({
 	inte,
