@@ -3,6 +3,7 @@ import { StyleSheet, TouchableOpacity, View } from 'react-native'
 
 import { UnifiedText } from '../../shared-components/UnifiedText'
 import { DropdownPriv } from '../Dropdown.priv'
+import { DropdownRef } from '../interfaces'
 
 type Item = {
 	label: string
@@ -13,20 +14,25 @@ interface TextualDropdownProps {
 	items: Item[]
 	onChangeItem: (item: Item) => void
 	placeholder: string
+	accessibilityLabel?: string
 }
 
 export const TextualDropdown: React.FC<TextualDropdownProps> = props => {
-	const childRef = useRef<{ toggleView: () => void }>()
+	const childRef = useRef<DropdownRef>(null)
 
 	return (
 		<View style={styles.container}>
-			<DropdownPriv ref={childRef} placeholder={props.placeholder}>
+			<DropdownPriv
+				ref={childRef}
+				placeholder={props.placeholder}
+				accessibilityLabel={props.accessibilityLabel}
+			>
 				{props.items.map(item => (
 					<TouchableOpacity
 						activeOpacity={0.9}
 						onPress={() => {
 							props.onChangeItem(item)
-							childRef.current?.toggleView()
+							childRef.current?.toggleView?.()
 						}}
 						style={styles.item}
 						key={`${item.label}-${item.value}`}
