@@ -20,10 +20,10 @@ import NotificationProvider from '@berty/contexts/notification.context'
 import { PermissionsProvider } from '@berty/contexts/permissions.context'
 import { AppDimensionsProvider, StyleProvider } from '@berty/contexts/styles'
 import { UIKittenProvider } from '@berty/contexts/uiKitten.context'
+import { useMountEffect, useThemeColor } from '@berty/hooks'
 import { isReadyRef, navigationRef } from '@berty/navigation'
 import { Navigation } from '@berty/navigation/stacks'
 import reduxStore from '@berty/redux/store'
-import { useThemeColor, useMountEffect } from '@berty/store'
 
 import { CustomIconsPack } from './custom-icons'
 import { FeatherIconsPack } from './feather-icons'
