@@ -12,10 +12,9 @@ import { useSelector } from 'react-redux'
 
 import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
 import { useStyles } from '@berty/contexts/styles'
-import { useAppDispatch } from '@berty/hooks'
+import { useAppDispatch, useThemeColor } from '@berty/hooks'
 import { selectHandledLink, setHandledLink } from '@berty/redux/reducers/ui.reducer'
 import * as RawComponents from '@berty/screens'
-import { useThemeColor } from '@berty/store'
 
 import { ScreensParams } from './types'
 
@@ -93,10 +92,10 @@ function useLinking(): [string | null, unknown] {
 	}, [])
 
 	useEffect(() => {
-		const handleOpenUrl = (ev: any) => {
-			console.log('handleOpenUrl:', ev.url)
+		const handleOpenUrl = (event: { url: string }) => {
+			console.log('handleOpenUrl:', event.url)
 			setUrl(null)
-			setUrl(ev.url)
+			setUrl(event.url)
 		}
 
 		// for initial render
@@ -508,28 +507,6 @@ export const Navigation: React.FC = React.memo(() => {
 					presentation: 'formSheet',
 				}}
 			/>
-			<NavigationStack.Screen
-				name={'Settings.DevicesAndBackup'}
-				component={Components.Settings.DevicesAndBackup}
-				options={{
-					headerStyle: {
-						backgroundColor: colors['secondary-background'],
-					},
-					title: t('settings.devices-backup.title'),
-					presentation: 'formSheet',
-				}}
-			/>
-			<NavigationStack.Screen
-				name={'Settings.Security'}
-				component={Components.Settings.Security}
-				options={{
-					headerStyle: {
-						backgroundColor: colors['secondary-background'],
-					},
-					title: t('settings.security.title'),
-					presentation: 'formSheet',
-				}}
-			/>
 			<NavigationStack.Screen
 				name={'Settings.Accounts'}
 				component={Components.Settings.Accounts}
