@@ -14,48 +14,40 @@ import { RESULTS } from 'react-native-permissions'
 import { useDispatch } from 'react-redux'
 
 import beapi from '@berty/api'
-import { AccordionAdd } from '@berty/components/modals/AccordionAdd.modal'
-import { AccordionEdit } from '@berty/components/modals/AccordionEdit.modal'
-import { ButtonSetting } from '@berty/components/shared-components'
-import { Toggle } from '@berty/components/shared-components/Toggle'
+import {
+	AltToggle,
+	BootstrapDropdown,
+	FloatingMenuToggleAlt,
+	RelayDropdown,
+	RendezvousDropdown,
+} from '@berty/components'
 import { UnifiedText } from '@berty/components/shared-components/UnifiedText'
 import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
-import { useModal } from '@berty/contexts/modal.context'
 import { useStyles } from '@berty/contexts/styles'
-import { useAppDispatch, useAppSelector, useCreateNewAccount } from '@berty/hooks'
+import {
+	useAppDispatch,
+	useAppSelector,
+	useCreateNewAccount,
+	useMountEffect,
+	useThemeColor,
+} from '@berty/hooks'
 import { ScreenFC, useNavigation } from '@berty/navigation'
 import {
-	addToBootstrap,
-	addToRendezvous,
 	disableEveryNodeLists,
 	enableEveryNodeLists,
-	modifyFromBootstrap,
-	modifyFromRendezvous,
-	modifyFromStaticRelay,
-	removeFromBootstrap,
-	removeFromRendezvous,
-	removeFromStaticRelay,
-	selectBootstrap,
 	selectEditedNetworkConfig,
-	selectRendezvous,
-	selectStaticRelay,
 	setCurrentNetworkConfig,
-	toggleFromBootstrap,
-	toggleFromRendezvous,
-	toggleFromStaticRelay,
 } from '@berty/redux/reducers/networkConfig.reducer'
-import {
-	Accordion,
-	AccordionAddItem,
-	AccordionItem,
-	AccordionRef,
-} from '@berty/screens/onboarding/CustomModeSettings/components/Accordion'
-import { useMountEffect, useThemeColor } from '@berty/store'
 import { accountClient } from '@berty/utils/accounts/accountClient'
 import { checkProximityPermission } from '@berty/utils/react-native/checkPermissions'
 import { getPermissions, PermissionType } from '@berty/utils/react-native/permissions'
 
-type AccordionRefsType = {
+interface AccordionRef {
+	open: () => void
+	close: () => void
+}
+
+interface AccordionRefs {
 	relay: RefObject<AccordionRef>
 	rdvp: RefObject<AccordionRef>
 	bootstrap: RefObject<AccordionRef>
@@ -129,7 +121,6 @@ const ConfigPart: React.FC<{
 }
 
 const Proximity: React.FC = () => {
-	const colors = useThemeColor()
 	const { t } = useTranslation()
 	const { navigate } = useNavigation()
 	const dispatch = useDispatch()
@@ -137,18 +128,11 @@ const Proximity: React.FC = () => {
 
 	return (
 		<View>
-			<ButtonSetting
-				name={t('onboarding.custom-mode.settings.off-grid.ble-button')}
-				color={colors['main-text']}
-				icon='expert-ble'
-				iconPack='custom'
-				iconColor='#6E6DFF'
-				actionIconColor={colors['main-text']}
-				backgroundColor={colors['input-background']}
-				toggled
-				toggleStatus='secondary'
-				varToggle={currentNetworkConfig?.bluetoothLe === beapi.account.NetworkConfig.Flag.Enabled}
-				actionToggle={async () => {
+			<FloatingMenuToggleAlt
+				pack='custom'
+				iconName='expert-ble'
+				isToggleOn={currentNetworkConfig?.bluetoothLe === beapi.account.NetworkConfig.Flag.Enabled}
+				onPress={async () => {
 					await checkProximityPermission({
 						setNetworkConfig: async (newConfig: beapi.account.INetworkConfig) => {
 							dispatch(setCurrentNetworkConfig(newConfig))
@@ -158,23 +142,18 @@ const Proximity: React.FC = () => {
 						navigate,
 					})
 				}}
-			/>
+			>
+				{t('onboarding.custom-mode.settings.off-grid.ble-button')}
+			</FloatingMenuToggleAlt>
 			{Platform.OS === 'ios' && (
-				<ButtonSetting
-					name={t('onboarding.custom-mode.settings.off-grid.mc-button')}
-					color={colors['main-text']}
-					icon='expert-ble'
-					iconPack='custom'
-					iconColor='#6E6DFF'
-					actionIconColor={colors['main-text']}
-					backgroundColor={colors['input-background']}
-					toggled
-					toggleStatus='secondary'
-					varToggle={
+				<FloatingMenuToggleAlt
+					pack='custom'
+					iconName='expert-ble'
+					isToggleOn={
 						currentNetworkConfig?.appleMultipeerConnectivity ===
 						beapi.account.NetworkConfig.Flag.Enabled
 					}
-					actionToggle={async () => {
+					onPress={async () => {
 						await checkProximityPermission({
 							setNetworkConfig: async (newConfig: beapi.account.INetworkConfig) => {
 								dispatch(setCurrentNetworkConfig(newConfig))
@@ -184,23 +163,18 @@ const Proximity: React.FC = () => {
 							navigate,
 						})
 					}}
-				/>
+				>
+					{t('onboarding.custom-mode.settings.off-grid.mc-button')}
+				</FloatingMenuToggleAlt>
 			)}
 			{Platform.OS === 'android' && (
-				<ButtonSetting
-					name={t('onboarding.custom-mode.settings.off-grid.nearby-button')}
-					color={colors['main-text']}
-					icon='expert-ble'
-					iconPack='custom'
-					iconColor='#6E6DFF'
-					actionIconColor={colors['main-text']}
-					backgroundColor={colors['input-background']}
-					toggled
-					toggleStatus='secondary'
-					varToggle={
+				<FloatingMenuToggleAlt
+					pack='custom'
+					iconName='expert-ble'
+					isToggleOn={
 						currentNetworkConfig?.androidNearby === beapi.account.NetworkConfig.Flag.Enabled
 					}
-					actionToggle={async () => {
+					onPress={async () => {
 						await checkProximityPermission({
 							setNetworkConfig: async (newConfig: beapi.account.INetworkConfig) => {
 								dispatch(setCurrentNetworkConfig(newConfig))
@@ -210,20 +184,15 @@ const Proximity: React.FC = () => {
 							navigate,
 						})
 					}}
-				/>
+				>
+					{t('onboarding.custom-mode.settings.off-grid.nearby-button')}
+				</FloatingMenuToggleAlt>
 			)}
-			<ButtonSetting
-				name={t('onboarding.custom-mode.settings.off-grid.mdns-button')}
-				color={colors['main-text']}
-				icon='expert-setting'
-				iconPack='custom'
-				iconColor='#6E6DFF'
-				actionIconColor={colors['main-text']}
-				backgroundColor={colors['input-background']}
-				toggled
-				toggleStatus='secondary'
-				varToggle={currentNetworkConfig?.mdns === beapi.account.NetworkConfig.Flag.Enabled}
-				actionToggle={async () => {
+			<FloatingMenuToggleAlt
+				pack='custom'
+				iconName='expert-setting'
+				isToggleOn={currentNetworkConfig?.mdns === beapi.account.NetworkConfig.Flag.Enabled}
+				onPress={async () => {
 					dispatch(
 						setCurrentNetworkConfig({
 							...currentNetworkConfig,
@@ -234,33 +203,25 @@ const Proximity: React.FC = () => {
 						}),
 					)
 				}}
-			/>
+			>
+				{t('onboarding.custom-mode.settings.off-grid.mdns-button')}
+			</FloatingMenuToggleAlt>
 		</View>
 	)
 }
 
-const Routing: React.FC<{ accordionRefs: AccordionRefsType }> = ({ accordionRefs }) => {
-	const colors = useThemeColor()
+const Routing: React.FC<{ accordionRefs: AccordionRefs }> = ({ accordionRefs }) => {
 	const { t } = useTranslation()
 	const dispatch = useAppDispatch()
-	const { hide, show } = useModal()
-	const rendezvous = useAppSelector(selectRendezvous)
 	const currentNetworkConfig = useAppSelector(selectEditedNetworkConfig)
 
 	return (
 		<View>
-			<ButtonSetting
-				name={t('onboarding.custom-mode.settings.routing.dht-button')}
-				color={colors['main-text']}
-				icon='expert-setting'
-				iconPack='custom'
-				iconColor='#6E6DFF'
-				actionIconColor={colors['main-text']}
-				backgroundColor={colors['input-background']}
-				toggled
-				toggleStatus='secondary'
-				varToggle={currentNetworkConfig?.dht === beapi.account.NetworkConfig.DHTFlag.DHTClient}
-				actionToggle={async () => {
+			<FloatingMenuToggleAlt
+				pack='custom'
+				iconName='expert-setting'
+				isToggleOn={currentNetworkConfig?.dht === beapi.account.NetworkConfig.DHTFlag.DHTClient}
+				onPress={async () => {
 					dispatch(
 						setCurrentNetworkConfig({
 							...currentNetworkConfig,
@@ -271,215 +232,16 @@ const Routing: React.FC<{ accordionRefs: AccordionRefsType }> = ({ accordionRefs
 						}),
 					)
 				}}
-			/>
-			<Accordion
-				title={t('onboarding.custom-mode.settings.routing.rdvp-button')}
-				icon='privacy'
-				ref={accordionRefs.rdvp}
 			>
-				{(rendezvous || []).map(({ alias, url, isEnabled, isEditable }, index) => (
-					<AccordionItem
-						key={`rendezvous-item-${index}`}
-						toggle={isEnabled}
-						value={alias}
-						onToggleChange={() => dispatch(toggleFromRendezvous(url))}
-						onPressModify={
-							isEditable
-								? () =>
-										show(
-											<AccordionEdit
-												title={t('onboarding.custom-mode.settings.modals.edit.title.rdvp')}
-												onEdit={data => {
-													dispatch(modifyFromRendezvous({ url, changes: data }))
-													hide()
-												}}
-												onDelete={() => {
-													dispatch(removeFromRendezvous(url))
-													hide()
-												}}
-												defaultAlias={alias}
-												defaultUrl={url}
-												alreadyExistingUrls={rendezvous
-													.map(({ url }) => url)
-													.filter((url): url is string => url !== undefined)}
-												alreadyExistingAliases={rendezvous
-													.map(({ alias }) => alias)
-													.filter((alias): alias is string => alias !== undefined)}
-											/>,
-										)
-								: undefined
-						}
-					/>
-				))}
-				<AccordionAddItem
-					onPress={() =>
-						show(
-							<AccordionAdd
-								title={t('onboarding.custom-mode.settings.modals.add.title.rdvp')}
-								onSubmit={data => {
-									dispatch(addToRendezvous(data))
-									hide()
-								}}
-								alreadyExistingAliases={rendezvous
-									.map(({ alias }) => alias)
-									.filter((alias): alias is string => alias !== undefined)}
-								alreadyExistingUrls={rendezvous
-									.map(({ url }) => url)
-									.filter((url): url is string => url !== undefined)}
-							/>,
-						)
-					}
-				/>
-			</Accordion>
+				{t('onboarding.custom-mode.settings.routing.dht-button')}
+			</FloatingMenuToggleAlt>
+
+			<RendezvousDropdown ref={accordionRefs.rdvp} />
 		</View>
 	)
 }
 
-const Access: React.FC<{ accordionRefs: AccordionRefsType }> = ({ accordionRefs }) => {
-	// const colors = useThemeColor()
-	// const navigation = useNavigation()
-	// const { t } = useTranslation()
-	const dispatch = useAppDispatch()
-	const { t } = useTranslation()
-	const { hide, show } = useModal()
-	const bootstrap = useAppSelector(selectBootstrap)
-	const staticRelay = useAppSelector(selectStaticRelay)
-
-	return (
-		<View>
-			<Accordion
-				title={t('onboarding.custom-mode.settings.access.relay-button')}
-				icon='earth'
-				ref={accordionRefs.relay}
-			>
-				{(staticRelay || []).map(({ alias, url, isEnabled, isEditable }, index) => (
-					<AccordionItem
-						key={`rendezvous-item-${index}`}
-						toggle={isEnabled}
-						value={alias}
-						onToggleChange={() => dispatch(toggleFromStaticRelay(url))}
-						onPressModify={
-							isEditable
-								? () =>
-										show(
-											<AccordionEdit
-												title={t('onboarding.custom-mode.settings.modals.edit.title.relay')}
-												onEdit={data => {
-													dispatch(modifyFromStaticRelay({ url, changes: data }))
-													hide()
-												}}
-												onDelete={() => {
-													dispatch(removeFromStaticRelay(url))
-													hide()
-												}}
-												defaultAlias={alias}
-												defaultUrl={url}
-												alreadyExistingUrls={staticRelay
-													.map(({ url }) => url)
-													.filter((url): url is string => url !== undefined)}
-												alreadyExistingAliases={staticRelay
-													.map(({ alias }) => alias)
-													.filter((alias): alias is string => alias !== undefined)}
-											/>,
-										)
-								: undefined
-						}
-					/>
-				))}
-				<AccordionAddItem
-					onPress={() =>
-						show(
-							<AccordionAdd
-								title={t('onboarding.custom-mode.settings.modals.add.title.relay')}
-								onSubmit={data => {
-									dispatch(addToRendezvous(data))
-									hide()
-								}}
-								alreadyExistingAliases={staticRelay
-									.map(({ alias }) => alias)
-									.filter((alias): alias is string => alias !== undefined)}
-								alreadyExistingUrls={staticRelay
-									.map(({ url }) => url)
-									.filter((url): url is string => url !== undefined)}
-							/>,
-						)
-					}
-				/>
-			</Accordion>
-			<Accordion
-				title={t('onboarding.custom-mode.settings.access.bootstrap-button')}
-				icon='earth'
-				ref={accordionRefs.bootstrap}
-			>
-				{(bootstrap || []).map(({ alias, url, isEnabled, isEditable }, index) => (
-					<AccordionItem
-						key={`rendezvous-item-${index}`}
-						toggle={isEnabled}
-						value={alias}
-						onToggleChange={() => dispatch(toggleFromBootstrap(url))}
-						onPressModify={
-							isEditable
-								? () =>
-										show(
-											<AccordionEdit
-												title={t('onboarding.custom-mode.settings.modals.edit.title.bootstrap')}
-												onEdit={data => {
-													dispatch(modifyFromBootstrap({ url, changes: data }))
-													hide()
-												}}
-												onDelete={() => {
-													dispatch(removeFromBootstrap(url))
-													hide()
-												}}
-												defaultAlias={alias}
-												defaultUrl={url}
-												alreadyExistingUrls={bootstrap
-													.map(({ url }) => url)
-													.filter((url): url is string => url !== undefined)}
-												alreadyExistingAliases={bootstrap
-													.map(({ alias }) => alias)
-													.filter((alias): alias is string => alias !== undefined)}
-											/>,
-										)
-								: undefined
-						}
-					/>
-				))}
-				<AccordionAddItem
-					onPress={() =>
-						show(
-							<AccordionAdd
-								title={t('onboarding.custom-mode.settings.modals.add.title.bootstrap')}
-								onSubmit={data => {
-									dispatch(addToBootstrap(data))
-									hide()
-								}}
-								alreadyExistingAliases={bootstrap
-									.map(({ alias }) => alias)
-									.filter((alias): alias is string => alias !== undefined)}
-								alreadyExistingUrls={bootstrap
-									.map(({ url }) => url)
-									.filter((url): url is string => url !== undefined)}
-							/>,
-						)
-					}
-				/>
-			</Accordion>
-			{/* <ButtonSetting
-				name={t('onboarding.custom-mode.settings.access.replication-button')}
-				icon='earth'
-				iconPack='custom'
-				color={colors['main-text']}
-				iconColor='#6E6DFF'
-				actionIconColor={colors['main-text']}
-				backgroundColor={colors['input-background']}
-				onPress={() => navigation.navigate('Settings.NetworkMap')}
-			/> */}
-		</View>
-	)
-}
-
-const CustomConfig: React.FC<{ accordionRefs: AccordionRefsType }> = ({ accordionRefs }) => {
+const CustomConfig: React.FC<{ accordionRefs: AccordionRefs }> = ({ accordionRefs }) => {
 	const { margin, padding, border } = useStyles()
 	const { t } = useTranslation()
 	const colors = useThemeColor()
@@ -521,7 +283,8 @@ const CustomConfig: React.FC<{ accordionRefs: AccordionRefsType }> = ({ accordio
 					icon='services'
 					iconSize={50}
 				/>
-				<Access accordionRefs={accordionRefs} />
+				<RelayDropdown ref={accordionRefs.relay} />
+				<BootstrapDropdown ref={accordionRefs.bootstrap} />
 			</View>
 		</View>
 	)
@@ -564,7 +327,7 @@ const ApplyChanges: React.FC = () => {
 	)
 }
 
-const EnableDisableAll: React.FC<{ accordionRefs: AccordionRefsType }> = ({ accordionRefs }) => {
+const EnableDisableAll: React.FC<{ accordionRefs: AccordionRefs }> = ({ accordionRefs }) => {
 	const { padding, border } = useStyles()
 	const colors = useThemeColor()
 	const [isToggled, setIsToggled] = React.useState(false)
@@ -609,9 +372,9 @@ const EnableDisableAll: React.FC<{ accordionRefs: AccordionRefsType }> = ({ acco
 				{t('onboarding.custom-mode.settings.all-button')}
 			</UnifiedText>
 			<View style={[padding.small]}>
-				<Toggle
+				<AltToggle
 					checked={isToggled}
-					status='third'
+					accessibilityLabel={t('onboarding.custom-mode.settings.all-button')}
 					onChange={async () => {
 						const toToggled = !isToggled
 						setIsToggled(toToggled)
@@ -664,7 +427,7 @@ export const CustomModeSettings: ScreenFC<'Onboarding.CustomModeSettings'> = ()
 	const colors = useThemeColor()
 	const { padding } = useStyles()
 	const dispatch = useAppDispatch()
-	const accordionRefs: AccordionRefsType = {
+	const accordionRefs: AccordionRefs = {
 		relay: createRef<AccordionRef>(),
 		rdvp: createRef<AccordionRef>(),
 		bootstrap: createRef<AccordionRef>(),
